==> wordpress_0.5.4.orig.tar.gz: wordpress-0.5.4.orig/src/WPData.cpp <==
/*
 * WPData.cpp
 *
 *  Created on: 12.11.2009
 *      Author: thyv
 */

#include "WPData.h"

void WPDataBlog::RemovePost(QString aPostId)
{
	const int count = iPosts.count();
	for (int i = 0; i < count; i++)
	{
		if (iPosts.at(i).iPostId == aPostId)
		{
			iPosts.removeAt(i);
			return;
		}
	}
}

void WPDataBlog::RemovePage(QString aPageId)
{
	const int count = iPages.count();
	for (int i = 0; i < count; i++)
	{
		if (iPages.at(i).iPageId == aPageId)
		{
			iPages.removeAt(i);
			return;
		}
	}
}

void WPDataBlog::RemoveLocalDraftPost(QString aPostId)
{
	const int count = iLocalDraftPosts.count();
	for (int i = 0; i < count; i++)
	{
		if (iLocalDraftPosts.at(i).iPostId == aPostId)
		{
			iLocalDraftPosts.removeAt(i);
			return;
		}
	}
}

void WPDataBlog::RemoveLocalDraftPage(QString aPageId)
{
	const int count = iLocalDraftPages.count();
	for (int i = 0; i < count; i++)
	{
		if (iLocalDraftPages.at(i).iPageId == aPageId)
		{
			iLocalDraftPages.removeAt(i);
			return;
		}
	}
}

bool WPDataPage::IsLocalDraft() const
{
	return iPageId.left(6) == "local_";
}

bool WPDataPage::IsDraftOrPending() const
{
	return IsLocalDraft() || iPageStatus == "draft" || iPageStatus == "pending";
}

bool WPDataPost::IsLocalDraft() const
{
	return iPostId.left(6) == "local_";
}

bool WPDataPost::IsDraftOrPending() const
{
	return IsLocalDraft() || iPostStatus == "draft" || iPostStatus == "pending";
}

QDataStream &operator<<(QDataStream &out, const WPDataUsersBlogs &dataUsersBlogs )
	{
	out << KDataUsersBlogsVersionNumber << dataUsersBlogs.iBlogs << dataUsersBlogs.iActiveBlogIndex;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataUsersBlogs &dataUsersBlogs )
	{
	in >> dataUsersBlogs.iDataUsersBlogsVersionNumber >> dataUsersBlogs.iBlogs >> dataUsersBlogs.iActiveBlogIndex;
	return in;
	}


QDataStream &operator<<(QDataStream &out, const WPDataBlog &dataBlog )
	{
	out << KDataBlogVersionNumber << dataBlog.iPages << dataBlog.iLocalDraftPages << dataBlog.iPosts 
		<< dataBlog.iLocalDraftPosts << dataBlog.iCategories << dataBlog.iTags << dataBlog.iComments
		<< dataBlog.iPageStatuses << dataBlog.iPostStatuses << dataBlog.iCommentStatuses
		<< dataBlog.iUsername << dataBlog.iPassword << dataBlog.iUrl << dataBlog.iRpcUrl
		<< dataBlog.iBlogName << dataBlog.iBlogId << dataBlog.iIsAdmin
                << dataBlog.iNumberOfPosts << dataBlog.iResizePhotos << dataBlog.iApiKey << dataBlog.iStats;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataBlog &dataBlog )
	{
	in >> dataBlog.iDataBlogVersionNumber >> dataBlog.iPages >> dataBlog.iLocalDraftPages >> dataBlog.iPosts 
		>> dataBlog.iLocalDraftPosts >> dataBlog.iCategories >> dataBlog.iTags >> dataBlog.iComments
		>> dataBlog.iPageStatuses >> dataBlog.iPostStatuses >> dataBlog.iCommentStatuses
		>> dataBlog.iUsername >> dataBlog.iPassword >> dataBlog.iUrl >> dataBlog.iRpcUrl
		>> dataBlog.iBlogName >> dataBlog.iBlogId >> dataBlog.iIsAdmin
                >> dataBlog.iNumberOfPosts >> dataBlog.iResizePhotos;

        if (dataBlog.iDataBlogVersionNumber >= 2)
            in >> dataBlog.iApiKey >> dataBlog.iStats;

	return in;
	}

QDataStream &operator<<(QDataStream &out, const WPDataPage &dataPage )
	{
	out << KDataPageVersionNumber << dataPage.iDateCreated << dataPage.iPageStatus << dataPage.iDescription << dataPage.iTitle 
		<< dataPage.iLink << dataPage.iPermaLink << dataPage.iExcerpt << dataPage.iTextMore << dataPage.iWpSlug 
		<< dataPage.iWpPassword << dataPage.iWpAuthor << dataPage.iWpPageParentTitle << dataPage.iWpAuthorDisplayName 
		<< dataPage.iDateCreatedGmt << dataPage.iWpPageTemplate << dataPage.iUserId << dataPage.iPageId 
		<< dataPage.iAllowComments << dataPage.iAllowPings << dataPage.iPageParentId << dataPage.iWpPageOrder << dataPage.iWpAuthorId; 
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataPage &dataPage )
	{
	in >> dataPage.iDataPageVersionNumber >> dataPage.iDateCreated >> dataPage.iPageStatus >> dataPage.iDescription >> dataPage.iTitle 
	>> dataPage.iLink >> dataPage.iPermaLink >> dataPage.iExcerpt >> dataPage.iTextMore >> dataPage.iWpSlug 
	>> dataPage.iWpPassword >> dataPage.iWpAuthor >> dataPage.iWpPageParentTitle >> dataPage.iWpAuthorDisplayName 
	>> dataPage.iDateCreatedGmt >> dataPage.iWpPageTemplate >> dataPage.iUserId >> dataPage.iPageId 
	>> dataPage.iAllowComments >> dataPage.iAllowPings >> dataPage.iPageParentId >> dataPage.iWpPageOrder >> dataPage.iWpAuthorId; 
	return in;
	}



QDataStream &operator<<(QDataStream &out, const WPDataCategory &dataPage )
	{
	out << KDataCategoryVersionNumber << dataPage.iCategoryId << dataPage.iParentId << dataPage.iDescription 
	<< dataPage.iCategoryDescription << dataPage.iCategoryName << dataPage.iHtmlUrl
	<< dataPage.iRssUrl;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataCategory &dataPage )
	{
	in >> dataPage.iDataCategoryVersionNumber >> dataPage.iCategoryId >> dataPage.iParentId >> dataPage.iDescription 
	>> dataPage.iCategoryDescription >> dataPage.iCategoryName >> dataPage.iHtmlUrl
	>> dataPage.iRssUrl;
	return in;
	}



QDataStream &operator<<(QDataStream &out, const WPDataPost &dataPost )
	{
	out << KDataPostVersionNumber << dataPost.iDateCreated << dataPost.iDescription << dataPost.iTitle 
		<< dataPost.iLink << dataPost.iPermaLink << dataPost.iUserId << dataPost.iPostId
		<< dataPost.iMtExcerpt << dataPost.iMtTextMore << dataPost.iMtAllowComments
		<< dataPost.iMtAllowPings << dataPost.iMtKeywords << dataPost.iWpSlug
		<< dataPost.iWpPassword << dataPost.iWpAuthorId << dataPost.iWpAuthorDisplayName
		<< dataPost.iDateCreatedGmt << dataPost.iPostStatus;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataPost &dataPost )
	{
	in >> dataPost.iDataPostVersionNumber >> dataPost.iDateCreated >> dataPost.iDescription >> dataPost.iTitle 
	>> dataPost.iLink >> dataPost.iPermaLink >> dataPost.iUserId >> dataPost.iPostId
	>> dataPost.iMtExcerpt >> dataPost.iMtTextMore >> dataPost.iMtAllowComments
	>> dataPost.iMtAllowPings >> dataPost.iMtKeywords >> dataPost.iWpSlug
	>> dataPost.iWpPassword >> dataPost.iWpAuthorId >> dataPost.iWpAuthorDisplayName
	>> dataPost.iDateCreatedGmt >> dataPost.iPostStatus;
	return in;
	}


QDataStream &operator<<(QDataStream &out, const WPDataTag &dataTag )
	{
	out << KDataTagVersionNumber << dataTag.iTagId << dataTag.iName << dataTag.iCount 
		<< dataTag.iSlug << dataTag.iHtmlUrl << dataTag.iRssUrl;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataTag &dataTag )
	{
	in >> dataTag.iDataTagVersionNumber >> dataTag.iTagId >> dataTag.iName >> dataTag.iCount 
	>> dataTag.iSlug >> dataTag.iHtmlUrl >> dataTag.iRssUrl;
	return in;
	}

QDataStream &operator<<(QDataStream &out, const WPDataComment &dataComment )
	{
	out << KDataCommentVersionNumber << dataComment.iDateCreatedGmt << dataComment.iUserId << dataComment.iCommentId 
		<< dataComment.iParent << dataComment.iStatus << dataComment.iContent
		<< dataComment.iLink << dataComment.iPostId << dataComment.iPostTitle
		<< dataComment.iAuthor << dataComment.iAuthorUrl << dataComment.iAuthorEmail
		<< dataComment.iAuthorIp << dataComment.iType;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataComment &dataComment )
	{
	in >> dataComment.iDataCommentVersionNumber >> dataComment.iDateCreatedGmt >> dataComment.iUserId >> dataComment.iCommentId 
		>> dataComment.iParent >> dataComment.iStatus >> dataComment.iContent
		>> dataComment.iLink >> dataComment.iPostId >> dataComment.iPostTitle
		>> dataComment.iAuthor >> dataComment.iAuthorUrl >> dataComment.iAuthorEmail
		>> dataComment.iAuthorIp >> dataComment.iType;
	return in;
	}

QDataStream &operator<<(QDataStream &out, const WPDataStats &dataStats )
        {
        out << KDataStatsVersionNumber << dataStats.iTotalVisits << dataStats.iDailyVisits;
        return out;
        }

QDataStream &operator>>(QDataStream &in, WPDataStats &dataStats )
        {
        in >> dataStats.iDataStatsVersionNumber >> dataStats.iTotalVisits >> dataStats.iDailyVisits;
        return in;
        }

==> wordpress_0.6.0.orig.tar.gz: wordpress-0.6.0.orig/src/WPData.cpp <==
/*
 * WPData.cpp
 *
 *  Created on: 12.11.2009
 *      Author: thyv
 */

#include "WPData.h"

void WPDataBlog::RemovePost(QString aPostId)
{
	const int count = iPosts.count();
	for (int i = 0; i < count; i++)
	{
		if (iPosts.at(i).iPostId == aPostId)
		{
			iPosts.removeAt(i);
			return;
		}
	}
}

void WPDataBlog::RemovePage(QString aPageId)
{
	const int count = iPages.count();
	for (int i = 0; i < count; i++)
	{
		if (iPages.at(i).iPageId == aPageId)
		{
			iPages.removeAt(i);
			return;
		}
	}
}

void WPDataBlog::RemoveLocalDraftPost(QString aPostId)
{
	const int count = iLocalDraftPosts.count();
	for (int i = 0; i < count; i++)
	{
		if (iLocalDraftPosts.at(i).iPostId == aPostId)
		{
			iLocalDraftPosts.removeAt(i);
			return;
		}
	}
}

void WPDataBlog::RemoveLocalDraftPage(QString aPageId)
{
	const int count = iLocalDraftPages.count();
	for (int i = 0; i < count; i++)
	{
		if (iLocalDraftPages.at(i).iPageId == aPageId)
		{
			iLocalDraftPages.removeAt(i);
			return;
		}
	}
}

bool WPDataPage::IsLocalDraft() const
{
	return iPageId.left(6) == "local_";
}

bool WPDataPage::IsDraftOrPending() const
{
	return IsLocalDraft() || iPageStatus == "draft" || iPageStatus == "pending";
}

bool WPDataPost::IsLocalDraft() const
{
	return iPostId.left(6) == "local_";
}

bool WPDataPost::IsDraftOrPending() const
{
	return IsLocalDraft() || iPostStatus == "draft" || iPostStatus == "pending";
}

QDataStream &operator<<(QDataStream &out, const WPDataUsersBlogs &dataUsersBlogs )
	{
	out << KDataUsersBlogsVersionNumber << dataUsersBlogs.iBlogs << dataUsersBlogs.iActiveBlogIndex;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataUsersBlogs &dataUsersBlogs )
	{
	in >> dataUsersBlogs.iDataUsersBlogsVersionNumber >> dataUsersBlogs.iBlogs >> dataUsersBlogs.iActiveBlogIndex;
	return in;
	}


QDataStream &operator<<(QDataStream &out, const WPDataBlog &dataBlog )
	{
	out << KDataBlogVersionNumber << dataBlog.iPages << dataBlog.iLocalDraftPages << dataBlog.iPosts 
		<< dataBlog.iLocalDraftPosts << dataBlog.iCategories << dataBlog.iTags << dataBlog.iComments
		<< dataBlog.iPageStatuses << dataBlog.iPostStatuses << dataBlog.iCommentStatuses
		<< dataBlog.iUsername << dataBlog.iPassword << dataBlog.iUrl << dataBlog.iRpcUrl
		<< dataBlog.iBlogName << dataBlog.iBlogId << dataBlog.iIsAdmin
                << dataBlog.iNumberOfPosts << dataBlog.iResizePhotos << dataBlog.iApiKey << dataBlog.iStats;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataBlog &dataBlog )
	{
	in >> dataBlog.iDataBlogVersionNumber >> dataBlog.iPages >> dataBlog.iLocalDraftPages >> dataBlog.iPosts 
		>> dataBlog.iLocalDraftPosts >> dataBlog.iCategories >> dataBlog.iTags >> dataBlog.iComments
		>> dataBlog.iPageStatuses >> dataBlog.iPostStatuses >> dataBlog.iCommentStatuses
		>> dataBlog.iUsername >> dataBlog.iPassword >> dataBlog.iUrl >> dataBlog.iRpcUrl
		>> dataBlog.iBlogName >> dataBlog.iBlogId >> dataBlog.iIsAdmin
                >> dataBlog.iNumberOfPosts >> dataBlog.iResizePhotos;

        if (dataBlog.iDataBlogVersionNumber >= 2)
            in >> dataBlog.iApiKey >> dataBlog.iStats;

	return in;
	}

QDataStream &operator<<(QDataStream &out, const WPDataPage &dataPage )
	{
	out << KDataPageVersionNumber << dataPage.iDateCreated << dataPage.iPageStatus << dataPage.iDescription << dataPage.iTitle 
		<< dataPage.iLink << dataPage.iPermaLink << dataPage.iExcerpt << dataPage.iTextMore << dataPage.iWpSlug 
		<< dataPage.iWpPassword << dataPage.iWpAuthor << dataPage.iWpPageParentTitle << dataPage.iWpAuthorDisplayName 
		<< dataPage.iDateCreatedGmt << dataPage.iWpPageTemplate << dataPage.iUserId << dataPage.iPageId 
		<< dataPage.iAllowComments << dataPage.iAllowPings << dataPage.iPageParentId << dataPage.iWpPageOrder << dataPage.iWpAuthorId; 
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataPage &dataPage )
	{
	in >> dataPage.iDataPageVersionNumber >> dataPage.iDateCreated >> dataPage.iPageStatus >> dataPage.iDescription >> dataPage.iTitle 
	>> dataPage.iLink >> dataPage.iPermaLink >> dataPage.iExcerpt >> dataPage.iTextMore >> dataPage.iWpSlug 
	>> dataPage.iWpPassword >> dataPage.iWpAuthor >> dataPage.iWpPageParentTitle >> dataPage.iWpAuthorDisplayName 
	>> dataPage.iDateCreatedGmt >> dataPage.iWpPageTemplate >> dataPage.iUserId >> dataPage.iPageId 
	>> dataPage.iAllowComments >> dataPage.iAllowPings >> dataPage.iPageParentId >> dataPage.iWpPageOrder >> dataPage.iWpAuthorId; 
	return in;
	}



QDataStream &operator<<(QDataStream &out, const WPDataCategory &dataPage )
	{
	out << KDataCategoryVersionNumber << dataPage.iCategoryId << dataPage.iParentId << dataPage.iDescription 
	<< dataPage.iCategoryDescription << dataPage.iCategoryName << dataPage.iHtmlUrl
	<< dataPage.iRssUrl;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataCategory &dataPage )
	{
	in >> dataPage.iDataCategoryVersionNumber >> dataPage.iCategoryId >> dataPage.iParentId >> dataPage.iDescription 
	>> dataPage.iCategoryDescription >> dataPage.iCategoryName >> dataPage.iHtmlUrl
	>> dataPage.iRssUrl;
	return in;
	}



QDataStream &operator<<(QDataStream &out, const WPDataPost &dataPost )
	{
	out << KDataPostVersionNumber << dataPost.iDateCreated << dataPost.iDescription << dataPost.iTitle 
		<< dataPost.iLink << dataPost.iPermaLink << dataPost.iUserId << dataPost.iPostId
		<< dataPost.iMtExcerpt << dataPost.iMtTextMore << dataPost.iMtAllowComments
		<< dataPost.iMtAllowPings << dataPost.iMtKeywords << dataPost.iWpSlug
		<< dataPost.iWpPassword << dataPost.iWpAuthorId << dataPost.iWpAuthorDisplayName
		<< dataPost.iDateCreatedGmt << dataPost.iPostStatus;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataPost &dataPost )
	{
	in >> dataPost.iDataPostVersionNumber >> dataPost.iDateCreated >> dataPost.iDescription >> dataPost.iTitle 
	>> dataPost.iLink >> dataPost.iPermaLink >> dataPost.iUserId >> dataPost.iPostId
	>> dataPost.iMtExcerpt >> dataPost.iMtTextMore >> dataPost.iMtAllowComments
	>> dataPost.iMtAllowPings >> dataPost.iMtKeywords >> dataPost.iWpSlug
	>> dataPost.iWpPassword >> dataPost.iWpAuthorId >> dataPost.iWpAuthorDisplayName
	>> dataPost.iDateCreatedGmt >> dataPost.iPostStatus;
	return in;
	}


QDataStream &operator<<(QDataStream &out, const WPDataTag &dataTag )
	{
	out << KDataTagVersionNumber << dataTag.iTagId << dataTag.iName << dataTag.iCount 
		<< dataTag.iSlug << dataTag.iHtmlUrl << dataTag.iRssUrl;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataTag &dataTag )
	{
	in >> dataTag.iDataTagVersionNumber >> dataTag.iTagId >> dataTag.iName >> dataTag.iCount 
	>> dataTag.iSlug >> dataTag.iHtmlUrl >> dataTag.iRssUrl;
	return in;
	}

QDataStream &operator<<(QDataStream &out, const WPDataComment &dataComment )
	{
	out << KDataCommentVersionNumber << dataComment.iDateCreatedGmt << dataComment.iUserId << dataComment.iCommentId 
		<< dataComment.iParent << dataComment.iStatus << dataComment.iContent
		<< dataComment.iLink << dataComment.iPostId << dataComment.iPostTitle
		<< dataComment.iAuthor << dataComment.iAuthorUrl << dataComment.iAuthorEmail
		<< dataComment.iAuthorIp << dataComment.iType;
	return out;
	}

QDataStream &operator>>(QDataStream &in, WPDataComment &dataComment )
	{
	in >> dataComment.iDataCommentVersionNumber >> dataComment.iDateCreatedGmt >> dataComment.iUserId >> dataComment.iCommentId 
		>> dataComment.iParent >> dataComment.iStatus >> dataComment.iContent
		>> dataComment.iLink >> dataComment.iPostId >> dataComment.iPostTitle
		>> dataComment.iAuthor >> dataComment.iAuthorUrl >> dataComment.iAuthorEmail
		>> dataComment.iAuthorIp >> dataComment.iType;
	return in;
	}

QDataStream &operator<<(QDataStream &out, const WPDataStats &dataStats )
        {
        out << KDataStatsVersionNumber << dataStats.iTotalVisits << dataStats.iVisits << dataStats.iSearchTerms << dataStats.iReferrers << dataStats.iLastUpdated;
        return out;
        }

QDataStream &operator>>(QDataStream &in, WPDataStats &dataStats )
        {
        in >> dataStats.iDataStatsVersionNumber >> dataStats.iTotalVisits;

        if (dataStats.iDataStatsVersionNumber == 1) {
            QList< QPair<QDate, int> > visits = QList< QPair<QDate, int> >();
            in >> visits;

            QPair<QDate, int> pair;
            foreach (pair, visits) {
                dataStats.iVisits.insert(pair.first, pair.second);
            }
        } else if (dataStats.iDataStatsVersionNumber >= 2) {
            in >> dataStats.iVisits >> dataStats.iSearchTerms >> dataStats.iReferrers;
        }

        if (dataStats.iDataStatsVersionNumber >= 3) {
            in >> dataStats.iLastUpdated;
        }

        return in;
        }
